@@ -1,14 +1,15 @@
-from pysal.cg import Point,LineSegment,Line,Ray,Chain,Rectangle,Polygon
+from pysal.cg import Point, LineSegment, Line, Ray, Chain, Rectangle, Polygon
 import doctest
 import unittest
 
+
 class test_Point(unittest.TestCase):
 
     def test___init__1(self):
         """
         Tests whether points are created without issue.
 
-        Test tag: <tc>#tests#Point.__init__</tc>    
+        Test tag: <tc>#tests#Point.__init__</tc>
         """
         for l in [(-5.0, 10.0), (0.0, -6.0), (float(1e300), float(-1e300))]:
             p = Point(l)
@@ -21,7 +22,9 @@ class test_Point(unittest.TestCase):
         """
         for l in [(-5, 10), (0, -6.0), (float(1e300), -1e300)]:
             p = Point(l)
-            self.assertEquals(str(p), str((float(l[0]), float(l[1])))) # Recast to floats like point does       
+            self.assertEquals(str(p), str((float(l[0]), float(
+                l[1]))))  # Recast to floats like point does
+
 
 class test_LineSegment(unittest.TestCase):
 
@@ -32,38 +35,44 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.is_ccw</tc>
         """
         ls = LineSegment(Point((0, 0)), Point((5, 0)))
-        self.assertFalse(ls.is_ccw(Point((10, 0)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((3, 0)))) # On segment
-        self.assertFalse(ls.is_ccw(Point((-10, 0)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((0, 0)))) # Endpoint of segment
-        self.assertFalse(ls.is_ccw(Point((5, 0)))) # Endpoint of segment
+        self.assertFalse(ls.is_ccw(
+            Point((10, 0))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((3, 0))))  # On segment
+        self.assertFalse(ls.is_ccw(
+            Point((-10, 0))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((0, 0))))  # Endpoint of segment
+        self.assertFalse(ls.is_ccw(Point((5, 0))))  # Endpoint of segment
 
     def test_is_ccw2(self):
         """
         Test corner cases for vertical segment ending at origin.
 
         Test tag: <tc>#tests#LineSegment.is_ccw</tc>
-        """ 
+        """
         ls = LineSegment(Point((0, -5)), Point((0, 0)))
-        self.assertFalse(ls.is_ccw(Point((0, 10)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((0, -3)))) # On segment
-        self.assertFalse(ls.is_ccw(Point((0, -10)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((0, -5)))) # Endpoint of segment
-        self.assertFalse(ls.is_ccw(Point((0, 0)))) # Endpoint of segment
+        self.assertFalse(ls.is_ccw(
+            Point((0, 10))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((0, -3))))  # On segment
+        self.assertFalse(ls.is_ccw(
+            Point((0, -10))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((0, -5))))  # Endpoint of segment
+        self.assertFalse(ls.is_ccw(Point((0, 0))))  # Endpoint of segment
 
     def test_is_ccw3(self):
         """
         Test corner cases for non-axis-aligned segment not through origin.
 
         Test tag: <tc>#tests#LineSegment.is_ccw</tc>
-        """ 
+        """
         ls = LineSegment(Point((0, 1)), Point((5, 6)))
-        self.assertFalse(ls.is_ccw(Point((10, 11)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((3, 4)))) # On segment
-        self.assertFalse(ls.is_ccw(Point((-10, -9)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_ccw(Point((0, 1)))) # Endpoint of segment
-        self.assertFalse(ls.is_ccw(Point((5, 6)))) # Endpoint of segment
-        
+        self.assertFalse(ls.is_ccw(
+            Point((10, 11))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((3, 4))))  # On segment
+        self.assertFalse(ls.is_ccw(
+            Point((-10, -9))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_ccw(Point((0, 1))))  # Endpoint of segment
+        self.assertFalse(ls.is_ccw(Point((5, 6))))  # Endpoint of segment
+
     def test_is_cw1(self):
         """
         Test corner cases for horizontal segment starting at origin.
@@ -71,11 +80,13 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.is_cw</tc>
         """
         ls = LineSegment(Point((0, 0)), Point((5, 0)))
-        self.assertFalse(ls.is_cw(Point((10, 0)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((3, 0)))) # On segment
-        self.assertFalse(ls.is_cw(Point((-10, 0)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((0, 0)))) # Endpoint of segment
-        self.assertFalse(ls.is_cw(Point((5, 0)))) # Endpoint of segment
+        self.assertFalse(ls.is_cw(
+            Point((10, 0))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((3, 0))))  # On segment
+        self.assertFalse(ls.is_cw(
+            Point((-10, 0))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((0, 0))))  # Endpoint of segment
+        self.assertFalse(ls.is_cw(Point((5, 0))))  # Endpoint of segment
 
     def test_is_cw2(self):
         """
@@ -84,11 +95,13 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.is_cw</tc>
         """
         ls = LineSegment(Point((0, -5)), Point((0, 0)))
-        self.assertFalse(ls.is_cw(Point((0, 10)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((0, -3)))) # On segment
-        self.assertFalse(ls.is_cw(Point((0, -10)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((0, -5)))) # Endpoint of segment
-        self.assertFalse(ls.is_cw(Point((0, 0)))) # Endpoint of segment
+        self.assertFalse(ls.is_cw(
+            Point((0, 10))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((0, -3))))  # On segment
+        self.assertFalse(ls.is_cw(
+            Point((0, -10))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((0, -5))))  # Endpoint of segment
+        self.assertFalse(ls.is_cw(Point((0, 0))))  # Endpoint of segment
 
     def test_is_cw3(self):
         """
@@ -97,11 +110,13 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.is_cw</tc>
         """
         ls = LineSegment(Point((0, 1)), Point((5, 6)))
-        self.assertFalse(ls.is_cw(Point((10, 11)))) # At positive boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((3, 4)))) # On segment
-        self.assertFalse(ls.is_cw(Point((-10, -9)))) # At negative boundary beyond segment
-        self.assertFalse(ls.is_cw(Point((0, 1)))) # Endpoint of segment
-        self.assertFalse(ls.is_cw(Point((5, 6)))) # Endpoint of segment
+        self.assertFalse(ls.is_cw(
+            Point((10, 11))))  # At positive boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((3, 4))))  # On segment
+        self.assertFalse(ls.is_cw(
+            Point((-10, -9))))  # At negative boundary beyond segment
+        self.assertFalse(ls.is_cw(Point((0, 1))))  # Endpoint of segment
+        self.assertFalse(ls.is_cw(Point((5, 6))))  # Endpoint of segment
 
     def test_get_swap1(self):
         """
@@ -136,22 +151,22 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.bounding_box</tc>
         """
         ls = LineSegment(Point((0, 0)), Point((0, 10)))
-        self.assertEquals(ls.bounding_box.left, 0) 
-        self.assertEquals(ls.bounding_box.lower, 0) 
-        self.assertEquals(ls.bounding_box.right, 0) 
-        self.assertEquals(ls.bounding_box.upper, 10) 
+        self.assertEquals(ls.bounding_box.left, 0)
+        self.assertEquals(ls.bounding_box.lower, 0)
+        self.assertEquals(ls.bounding_box.right, 0)
+        self.assertEquals(ls.bounding_box.upper, 10)
 
         ls = LineSegment(Point((0, 0)), Point((-3, -4)))
-        self.assertEquals(ls.bounding_box.left, -3) 
-        self.assertEquals(ls.bounding_box.lower, -4) 
-        self.assertEquals(ls.bounding_box.right, 0) 
-        self.assertEquals(ls.bounding_box.upper, 0) 
+        self.assertEquals(ls.bounding_box.left, -3)
+        self.assertEquals(ls.bounding_box.lower, -4)
+        self.assertEquals(ls.bounding_box.right, 0)
+        self.assertEquals(ls.bounding_box.upper, 0)
 
         ls = LineSegment(Point((-5, 0)), Point((3, 0)))
-        self.assertEquals(ls.bounding_box.left, -5) 
-        self.assertEquals(ls.bounding_box.lower, 0) 
-        self.assertEquals(ls.bounding_box.right, 3) 
-        self.assertEquals(ls.bounding_box.upper, 0) 
+        self.assertEquals(ls.bounding_box.left, -5)
+        self.assertEquals(ls.bounding_box.lower, 0)
+        self.assertEquals(ls.bounding_box.right, 3)
+        self.assertEquals(ls.bounding_box.upper, 0)
 
     def test_len1(self):
         """
@@ -160,33 +175,34 @@ class test_LineSegment(unittest.TestCase):
         Test tag: <tc>#tests#LineSegment.len</tc>
         """
         ls = LineSegment(Point((0, 0)), Point((0, 0)))
-        self.assertEquals(ls.len, 0) 
-         
+        self.assertEquals(ls.len, 0)
+
         ls = LineSegment(Point((0, 0)), Point((-3, 0)))
-        self.assertEquals(ls.len, 3) 
+        self.assertEquals(ls.len, 3)
 
     def test_line1(self):
         """
         Tests corner cases.
 
         Test tag: <tc>#tests#LineSegment.line</tc>
-        """         
+        """
         import math
         ls = LineSegment(Point((0, 0)), Point((1, 0)))
-        self.assertEquals(ls.line.m, 0) 
-        self.assertEquals(ls.line.b, 0) 
+        self.assertEquals(ls.line.m, 0)
+        self.assertEquals(ls.line.b, 0)
 
         ls = LineSegment(Point((0, 0)), Point((0, 1)))
         self.assertEquals(ls.line.m, float('inf'))
         self.assertTrue(math.isnan(ls.line.b))
-        
+
         ls = LineSegment(Point((0, 0)), Point((0, -1)))
         self.assertEquals(ls.line.m, float('inf'))
         self.assertTrue(math.isnan(ls.line.b))
-   
-        ls  = LineSegment(Point((0, 0)), Point((0, 0)))
+
+        ls = LineSegment(Point((0, 0)), Point((0, 0)))
         self.assertEquals(ls.line, None)
-     
+
+
 class test_Line(unittest.TestCase):
 
     def test___init__1(self):
@@ -195,8 +211,8 @@ class test_Line(unittest.TestCase):
 
         Test tag: <tc>#tests#Line.__init__</tc>
         """
-        for m,b in [(4, 0.0), (-140, 5), (0, 0)]:
-            l = Line(m, b) 
+        for m, b in [(4, 0.0), (-140, 5), (0, 0)]:
+            l = Line(m, b)
 
     def test_y1(self):
         """
@@ -213,7 +229,7 @@ class test_Line(unittest.TestCase):
         self.assertEquals(l.y(2), 3)
         self.assertEquals(l.y(-1e600), -1e600)
         self.assertEquals(l.y(1e600), 1e600)
- 
+
         l = Line(-1, 1)
         self.assertEquals(l.y(2), -1)
         self.assertEquals(l.y(-1e600), 1e600)
@@ -238,12 +254,13 @@ class test_Line(unittest.TestCase):
         self.assertEquals(l.x(3), 2)
         self.assertEquals(l.x(-1e600), -1e600)
         self.assertEquals(l.x(1e600), 1e600)
- 
+
         l = Line(-1, 1)
         self.assertEquals(l.x(2), -1)
         self.assertEquals(l.x(-1e600), 1e600)
         self.assertEquals(l.x(1e600), -1e600)
 
+
 class test_Ray(unittest.TestCase):
 
     def test___init__1(self):
@@ -255,6 +272,7 @@ class test_Ray(unittest.TestCase):
         r = Ray(Point((0, 0)), Point((1, 1)))
         r = Ray(Point((8, -3)), Point((-5, 9)))
 
+
 class test_Chain(unittest.TestCase):
 
     def test___init__1(self):
@@ -265,7 +283,7 @@ class test_Chain(unittest.TestCase):
         """
         c = Chain([Point((0, 0))])
         c = Chain([[Point((0, 0)), Point((1, 1))], [Point((2, 5))]])
-    
+
     def test_vertices1(self):
         """
         Testing for repeated vertices and multiple parts.
@@ -279,13 +297,13 @@ class test_Chain(unittest.TestCase):
         vertices = [[Point((0, 0)), Point((1, 1)), Point((2, 5))],
                     [Point((0, 0)), Point((1, 1)), Point((2, 5))]]
         self.assertEquals(Chain(vertices).vertices, vertices[0] + vertices[1])
-   
+
     def test_parts1(self):
         """
         Generic testing of parts functionality.
 
         Test tag: <tc>#tests#Chain.parts</tc>
-        """ 
+        """
         vertices = [Point((0, 0)), Point((1, 1)), Point((2, 5)),
                     Point((0, 0)), Point((1, 1)), Point((2, 5))]
         self.assertEquals(Chain(vertices).parts, [vertices])
@@ -316,14 +334,15 @@ class test_Chain(unittest.TestCase):
         """
         vertices = [[Point((0, 0)), Point((1, 0)), Point((1, 5))],
                     [Point((-5, -5)), Point((-5, 0)), Point((0, 0)), Point((0, 0))]]
-        self.assertEquals(Chain(vertices).len, 6 + 10) 
+        self.assertEquals(Chain(vertices).len, 6 + 10)
+
 
 class test_Polygon(unittest.TestCase):
 
     def test___init__1(self):
         """
         Test various input configurations (list vs. lists of lists, holes)
- 
+
         <tc>#tests#Polygon.__init__</tc>
         """
         # Input configurations tested (in order of test):
@@ -333,21 +352,35 @@ class test_Polygon(unittest.TestCase):
         # multi part, one hole
         # one part, multi holes
         # multi part, multi holes
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))]) 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))]) 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]], 
-                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))]) 
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]]) 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]], 
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]]) 
+        p = Polygon([Point(
+            (0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))])
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))])
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point(
+                         (
+                             30, 30)), Point(
+                                 (40, 30)), Point((40, 40)), Point((30, 40))]],
+                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))])
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]])
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point(
+                         (
+                             30, 30)), Point(
+                                 (40, 30)), Point((40, 40)), Point((30, 40))]],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]])
 
     def test_area1(self):
         """
@@ -355,9 +388,10 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.area</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
-        self.assertEquals(p.area, 200) 
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
+        self.assertEquals(p.area, 200)
 
     def test_area2(self):
         """
@@ -365,19 +399,27 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.area</tc>
         """
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))]) 
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))])
         self.assertEquals(p.area, 100 - 4)
 
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]]) 
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]])
         self.assertEquals(p.area, 100 - (4 + 4))
 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]], 
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((36, 36)), Point((36, 38)), Point((38, 38)), Point((38, 36))]]) 
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point(
+                         (
+                             30, 30)), Point(
+                                 (40, 30)), Point((40, 40)), Point((30, 40))]],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((36, 36)), Point((36, 38)), Point((38, 38)), Point((38, 36))]])
         self.assertEquals(p.area, 200 - (4 + 4))
 
     def test_area4(self):
@@ -386,10 +428,12 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.area</tc>
         """
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))]) 
+        p = Polygon([Point(
+            (0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))])
         self.assertEquals(p.area, 100)
 
-        p = Polygon([Point((0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))]) 
+        p = Polygon([Point(
+            (0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))])
         self.assertEquals(p.area, 100)
 
     def test_bounding_box1(self):
@@ -398,8 +442,9 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.bounding_box</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
         bb = p.bounding_box
         self.assertEquals(bb.left, 0)
         self.assertEquals(bb.lower, 0)
@@ -411,9 +456,10 @@ class test_Polygon(unittest.TestCase):
         Test polygons with multiple parts of the same size.
 
         Test tag: <tc>#tests#Polygon.centroid</tc>
-        """ 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
+        """
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
         c = p.centroid
         self.assertEquals(c[0], 20)
         self.assertEquals(c[1], 20)
@@ -423,9 +469,10 @@ class test_Polygon(unittest.TestCase):
         Test polygons with multiple parts of different size.
 
         Test tag: <tc>#tests#Polygon.centroid</tc>
-        """ 
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((35, 30)), Point((35, 35)), Point((30, 35))]]) 
+        """
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((35, 30)), Point((35, 35)), Point((30, 35))]])
         c = p.centroid
         self.assertEquals(c[0], 10.5)
         self.assertEquals(c[1], 10.5)
@@ -436,11 +483,13 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.holes</tc>
         """
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))]) 
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))])
         self.assertEquals(len(p.holes), 1)
-        e_holes = [Point((2, 2)), Point((2, 4)), Point((4, 4)), Point((4, 2))] 
-        self.assertTrue(p.holes[0] in [e_holes, [e_holes[-1]] + e_holes[:3], e_holes[-2:] + e_holes[:2], e_holes[-3:] + [e_holes[0]]])
+        e_holes = [Point((2, 2)), Point((2, 4)), Point((4, 4)), Point((4, 2))]
+        self.assertTrue(p.holes[0] in [e_holes, [e_holes[-1]] + e_holes[:3],
+                                       e_holes[-2:] + e_holes[:2], e_holes[-3:] + [e_holes[0]]])
 
     def test_holes2(self):
         """
@@ -448,9 +497,11 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.holes</tc>
         """
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]]) 
+        p = Polygon(
+            [Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]])
         holes = p.holes
         self.assertEquals(len(holes), 2)
 
@@ -460,18 +511,24 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.parts</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((30, 40))]]) 
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((30, 40))]])
         self.assertEquals(len(p.parts), 2)
 
-        part1 = [Point((0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))]
-        part2 = [Point((30, 30)), Point((30, 40)), Point((40, 30))] 
+        part1 = [Point(
+            (0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))]
+        part2 = [Point((30, 30)), Point((30, 40)), Point((40, 30))]
         if len(p.parts[0]) == 4:
-            self.assertTrue(p.parts[0] in [part1, part1[-1:] + part1[:3], part1[-2:] + part1[:2], part1[-3:] + part1[:1]])
-            self.assertTrue(p.parts[1] in [part2, part2[-1:] + part2[:2], part2[-2:] + part2[:1]])
+            self.assertTrue(p.parts[0] in [part1, part1[-1:] + part1[:3],
+                                           part1[-2:] + part1[:2], part1[-3:] + part1[:1]])
+            self.assertTrue(p.parts[1] in [part2, part2[-1:] +
+                                           part2[:2], part2[-2:] + part2[:1]])
         elif len(p.parts[0]) == 3:
-            self.assertTrue(p.parts[0] in [part2, part2[-1:] + part2[:2], part2[-2:] + part2[:1]])
-            self.assertTrue(p.parts[1] in [part1, part1[-1:] + part1[:3], part1[-2:] + part1[:2], part1[-3:] + part1[:1]])
+            self.assertTrue(p.parts[0] in [part2, part2[-1:] +
+                                           part2[:2], part2[-2:] + part2[:1]])
+            self.assertTrue(p.parts[1] in [part1, part1[-1:] + part1[:3],
+                                           part1[-2:] + part1[:2], part1[-3:] + part1[:1]])
         else:
             self.fail()
 
@@ -481,9 +538,10 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.perimeter</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
-        self.assertEquals(p.perimeter, 80)    
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
+        self.assertEquals(p.perimeter, 80)
 
     def test_perimeter2(self):
         """
@@ -491,45 +549,51 @@ class test_Polygon(unittest.TestCase):
 
         Test tag: <tc>#tests#Polygon.perimeter</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]], 
-                    holes=[[Point((2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
-                           [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]]) 
-        self.assertEquals(p.perimeter, 80 + 16)    
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point(
+                         (
+                             30, 30)), Point(
+                                 (40, 30)), Point((40, 40)), Point((30, 40))]],
+                    holes=[[Point(
+                        (2, 2)), Point((4, 2)), Point((4, 4)), Point((2, 4))],
+                        [Point((6, 6)), Point((6, 8)), Point((8, 8)), Point((8, 6))]])
+        self.assertEquals(p.perimeter, 80 + 16)
 
     def test_vertices1(self):
         """
         Test for correct values/order of vertices.
- 
+
         Test tag: <tc>#tests#Polygon.vertices</tc>
         """
-        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))])
+        p = Polygon([Point(
+            (0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))])
         self.assertEquals(len(p.vertices), 4)
-        e_verts = [Point((0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))] 
-        self.assertTrue(p.vertices in [e_verts, e_verts[-1:] + e_verts[:3], e_verts[-2:] + e_verts[:2], e_verts[-3:] + e_verts[:1]])
-        
+        e_verts = [Point(
+            (0, 0)), Point((0, 10)), Point((10, 10)), Point((10, 0))]
+        self.assertTrue(p.vertices in [e_verts, e_verts[-1:] + e_verts[:3],
+                                       e_verts[-2:] + e_verts[:2], e_verts[-3:] + e_verts[:1]])
+
     def test_vertices2(self):
         """
         Test for multiple parts.
- 
+
         Test tag: <tc>#tests#Polygon.vertices</tc>
         """
-        p = Polygon([[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
-                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]]) 
+        p = Polygon(
+            [[Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))],
+                     [Point((30, 30)), Point((40, 30)), Point((40, 40)), Point((30, 40))]])
         self.assertEquals(len(p.vertices), 8)
 
     def test_contains_point(self):
-         p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))], [Point((1, 2)), Point((2, 2)), Point((2, 1)), Point((1, 1))])
-         self.assertEquals(p.contains_point((0,0)), 1)
-         self.assertEquals(p.contains_point((1,1)), 0)
-         self.assertEquals(p.contains_point((2,2)), 1)
-         self.assertEquals(p.contains_point((5,5)), 1)
-         self.assertEquals(p.contains_point((10,10)), 0)
+        p = Polygon([Point((0, 0)), Point((10, 0)), Point((10, 10)), Point((0, 10))], [Point((1, 2)), Point((2, 2)), Point((2, 1)), Point((1, 1))])
+        self.assertEquals(p.contains_point((0, 0)), 1)
+        self.assertEquals(p.contains_point((1, 1)), 0)
+        self.assertEquals(p.contains_point((2, 2)), 1)
+        self.assertEquals(p.contains_point((5, 5)), 1)
+        self.assertEquals(p.contains_point((10, 10)), 0)
 
 
-        
-     
-
 class test_Rectangle(unittest.TestCase):
 
     def test___init__1(self):
@@ -539,14 +603,14 @@ class test_Rectangle(unittest.TestCase):
         Test tag: <tc>#tests#Rectangle.__init__</tc>
         """
         try:
-            r = Rectangle(1, 1, -1, 5) # right < left
+            r = Rectangle(1, 1, -1, 5)  # right < left
         except ArithmeticError:
             pass
         else:
             self.fail()
 
         try:
-            r = Rectangle(1, 1, 5, -1) # upper < lower
+            r = Rectangle(1, 1, 5, -1)  # upper < lower
         except ArithmeticError:
             pass
         else:
@@ -558,33 +622,33 @@ class test_Rectangle(unittest.TestCase):
 
         Test tag: <tc>#tests#Rectangle.set_centroid</tc>
         """
-        r = Rectangle(5, 5, 5, 10) # Zero width
+        r = Rectangle(5, 5, 5, 10)  # Zero width
         r.set_centroid(Point((0, 0)))
         self.assertEquals(r.left, 0)
         self.assertEquals(r.lower, -2.5)
         self.assertEquals(r.right, 0)
         self.assertEquals(r.upper, 2.5)
 
-        r = Rectangle(10, 5, 20, 5) # Zero height
+        r = Rectangle(10, 5, 20, 5)  # Zero height
         r.set_centroid(Point((40, 40)))
         self.assertEquals(r.left, 35)
         self.assertEquals(r.lower, 40)
         self.assertEquals(r.right, 45)
         self.assertEquals(r.upper, 40)
-        
-        r = Rectangle(0, 0, 0, 0) # Zero width and height
+
+        r = Rectangle(0, 0, 0, 0)  # Zero width and height
         r.set_centroid(Point((-4, -4)))
         self.assertEquals(r.left, -4)
         self.assertEquals(r.lower, -4)
         self.assertEquals(r.right, -4)
         self.assertEquals(r.upper, -4)
-        
+
     def test_set_scale1(self):
         """
         Test repeated scaling.
 
         Test tag: <tc>#tests#Rectangle.set_scale</tc>
-        """ 
+        """
         r = Rectangle(2, 2, 4, 4)
 
         r.set_scale(0.5)
@@ -592,60 +656,60 @@ class test_Rectangle(unittest.TestCase):
         self.assertEquals(r.lower, 2.5)
         self.assertEquals(r.right, 3.5)
         self.assertEquals(r.upper, 3.5)
-        
+
         r.set_scale(2)
         self.assertEquals(r.left, 2)
         self.assertEquals(r.lower, 2)
         self.assertEquals(r.right, 4)
         self.assertEquals(r.upper, 4)
-        
+
     def test_set_scale2(self):
         """
         Test scaling of rectangles with zero width/height..
 
         Test tag: <tc>#tests#Rectangle.set_scale</tc>
-        """ 
-        r = Rectangle(5, 5, 5, 10) # Zero width
-        r.set_scale(2) 
+        """
+        r = Rectangle(5, 5, 5, 10)  # Zero width
+        r.set_scale(2)
         self.assertEquals(r.left, 5)
         self.assertEquals(r.lower, 2.5)
         self.assertEquals(r.right, 5)
         self.assertEquals(r.upper, 12.5)
 
-        r = Rectangle(10, 5, 20, 5) # Zero height
-        r.set_scale(2) 
+        r = Rectangle(10, 5, 20, 5)  # Zero height
+        r.set_scale(2)
         self.assertEquals(r.left, 5)
         self.assertEquals(r.lower, 5)
         self.assertEquals(r.right, 25)
         self.assertEquals(r.upper, 5)
-        
-        r = Rectangle(0, 0, 0, 0) # Zero width and height
+
+        r = Rectangle(0, 0, 0, 0)  # Zero width and height
         r.set_scale(100)
         self.assertEquals(r.left, 0)
         self.assertEquals(r.lower, 0)
         self.assertEquals(r.right, 0)
         self.assertEquals(r.upper, 0)
 
-        r = Rectangle(0, 0, 0, 0) # Zero width and height
+        r = Rectangle(0, 0, 0, 0)  # Zero width and height
         r.set_scale(0.01)
         self.assertEquals(r.left, 0)
         self.assertEquals(r.lower, 0)
         self.assertEquals(r.right, 0)
         self.assertEquals(r.upper, 0)
-        
+
     def test_area1(self):
         """
         Test rectangles with zero width/height
 
         Test tag: <tc>#tests#Rectangle.area</tc>
         """
-        r = Rectangle(5, 5, 5, 10) # Zero width
+        r = Rectangle(5, 5, 5, 10)  # Zero width
         self.assertEquals(r.area, 0)
 
-        r = Rectangle(10, 5, 20, 5) # Zero height
+        r = Rectangle(10, 5, 20, 5)  # Zero height
         self.assertEquals(r.area, 0)
-        
-        r = Rectangle(0, 0, 0, 0) # Zero width and height
+
+        r = Rectangle(0, 0, 0, 0)  # Zero width and height
         self.assertEquals(r.area, 0)
 
     def test_height1(self):
@@ -654,7 +718,7 @@ class test_Rectangle(unittest.TestCase):
 
         Test tag: <tc>#tests#Rectangle.height</tc>
         """
-        r = Rectangle(10, 5, 20, 5) # Zero height
+        r = Rectangle(10, 5, 20, 5)  # Zero height
         self.assertEquals(r.height, 0)
 
     def test_width1(self):
@@ -663,11 +727,10 @@ class test_Rectangle(unittest.TestCase):
 
         Test tag: <tc>#tests#Rectangle.width</tc>
         """
-        r = Rectangle(5, 5, 5, 10) # Zero width
+        r = Rectangle(5, 5, 5, 10)  # Zero width
         self.assertEquals(r.width, 0)
 
 
-
 #suite = unittest.TestSuite()
 #suite.addTest(doctest.DocTestSuite('pysal.cg.shapes'))
 #A = unittest.TestLoader().loadTestsFromTestCase(_TestPoint)
@@ -678,7 +741,6 @@ class test_Rectangle(unittest.TestCase):
 #F = unittest.TestLoader().loadTestsFromTestCase(_TestPolygon)
 #G = unittest.TestLoader().loadTestsFromTestCase(_TestRectangle)
 #suite.addTests([A,B,C,D,E,D,G])
-
 if __name__ == '__main__':
     unittest.main()
     #runner = unittest.TextTestRunner()
