@@ -17,7 +17,7 @@ class TestBaseGMErrorHet(unittest.TestCase):
         self.w.transform = 'r'
 
     def test_model(self):
-        reg = HET.BaseGM_Error_Het(self.y, self.X, self.w, step1c=True)
+        reg = HET.BaseGM_Error_Het(self.y, self.X, self.w.sparse, step1c=True)
         betas = np.array([[ 47.99626638], [  0.71048989], [ -0.55876126], [  0.41178776]])
         np.testing.assert_array_almost_equal(reg.betas,betas,7)
         u = np.array([ 27.38122697])
@@ -136,7 +136,7 @@ class TestBaseGMEndogErrorHet(unittest.TestCase):
         self.w.transform = 'r'
 
     def test_model(self):
-        reg = HET.BaseGM_Endog_Error_Het(self.y, self.X, self.yd, self.q, self.w, step1c=True)
+        reg = HET.BaseGM_Endog_Error_Het(self.y, self.X, self.yd, self.q, self.w.sparse, step1c=True)
         betas = np.array([[ 55.39707924], [  0.46563046], [ -0.67038326], [  0.41135023]])
         np.testing.assert_array_almost_equal(reg.betas,betas,7)
         u = np.array([ 26.51812895])
@@ -269,7 +269,7 @@ class TestBaseGMComboHet(unittest.TestCase):
         # Only spatial lag
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, 1, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = HET.BaseGM_Combo_Het(self.y, self.X, yend=yd2, q=q2, w=self.w, step1c=True)
+        reg = HET.BaseGM_Combo_Het(self.y, self.X, yend=yd2, q=q2, w=self.w.sparse, step1c=True)
         betas = np.array([[ 57.7778574 ], [  0.73034922], [ -0.59257362], [ -0.2230231 ], [  0.56636724]])
         np.testing.assert_array_almost_equal(reg.betas,betas,7)
         u = np.array([ 25.65156033])
