@@ -20,7 +20,7 @@ class BaseGM_Error_Hom_Tester(unittest.TestCase):
         self.w = pysal.rook_from_shapefile(pysal.examples.get_path("columbus.shp"))
         self.w.transform = 'r'
     def test_model(self):
-        reg = HOM.BaseGM_Error_Hom(self.y, self.X, self.w, A1='hom_sc')
+        reg = HOM.BaseGM_Error_Hom(self.y, self.X, self.w.sparse, A1='hom_sc')
         np.testing.assert_array_almost_equal(reg.y[0],np.array([80.467003]),7)
         x = np.array([  1.     ,  19.531  ,  15.72598])
         np.testing.assert_array_almost_equal(reg.x[0],x,7)
@@ -102,7 +102,7 @@ class BaseGM_Endog_Error_Hom_Tester(unittest.TestCase):
         self.w = pysal.rook_from_shapefile(pysal.examples.get_path("columbus.shp"))
         self.w.transform = 'r'
     def test_model(self):
-        reg = HOM.BaseGM_Endog_Error_Hom(self.y, self.X, self.yd, self.q, self.w, A1='hom_sc')
+        reg = HOM.BaseGM_Endog_Error_Hom(self.y, self.X, self.yd, self.q, self.w.sparse, A1='hom_sc')
         np.testing.assert_array_almost_equal(reg.y[0],np.array([ 80.467003]),7)
         x = np.array([  1.     ,  19.531])
         np.testing.assert_array_almost_equal(reg.x[0],x,7)
@@ -212,7 +212,7 @@ class BaseGM_Combo_Hom_Tester(unittest.TestCase):
     def test_model(self):
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, 1, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = HOM.BaseGM_Combo_Hom(self.y, self.X, yend=yd2, q=q2, w=self.w, A1='hom_sc')
+        reg = HOM.BaseGM_Combo_Hom(self.y, self.X, yend=yd2, q=q2, w=self.w.sparse, A1='hom_sc')
         np.testing.assert_array_almost_equal(reg.y[0],np.array([80.467003]),7)
         x = np.array([  1.     ,  19.531])
         np.testing.assert_array_almost_equal(reg.x[0],x,7)
@@ -241,8 +241,8 @@ class BaseGM_Combo_Hom_Tester(unittest.TestCase):
         self.assertAlmostEqual(reg.mean_y,my)
         std_y = 18.466069465206047
         self.assertAlmostEqual(reg.std_y,std_y)
-        sig2 = 232.22680650302124
-        self.assertAlmostEqual(reg.sig2,sig2)
+        sig2 = 232.22680651270042
+        np.testing.assert_array_almost_equal(reg.sig2,sig2)
         hth = np.array([[    49.        ,    704.371999  ,    724.7435916 ], [   704.371999  ,  11686.67338121,  11092.519988  ], [   724.7435916 ,  11092.519988  , 11614.62257048]])
         np.testing.assert_array_almost_equal(reg.hth,hth,4)
 
@@ -290,8 +290,8 @@ class GM_Combo_Hom_Tester(unittest.TestCase):
         self.assertAlmostEqual(reg.pr2,pr2)
         pr2_e = 0.25082892555141506
         self.assertAlmostEqual(reg.pr2_e,pr2_e)
-        sig2 = 232.22680650302124 
-        self.assertAlmostEqual(reg.sig2,sig2)
+        sig2 = 232.22680651270042
+        np.testing.assert_array_almost_equal(reg.sig2,sig2)
         std_err = np.array([ 15.28707761,   0.44072838,   0.40479714, 0.42263726])
         np.testing.assert_array_almost_equal(reg.std_err,std_err,6)
         z_stat = np.array([[  6.62351206e-01,   5.07746167e-01], [  3.55847888e+00,   3.73008780e-04], [  3.73818749e-01,   7.08539170e-01], [  4.97670189e-01,   6.18716523e-01]])
