@@ -2,7 +2,7 @@ import unittest
 import numpy as np
 import pysal
 import pysal.spreg.diagnostics as D
-from pysal.spreg.twosls_sp import GM_Lag, BaseGM_Lag
+from pysal.spreg.twosls_sp import BaseGM_Lag, GM_Lag
 
 class TestBaseGMLag(unittest.TestCase):
     def setUp(self):
@@ -20,7 +20,7 @@ class TestBaseGMLag(unittest.TestCase):
         self.X = np.array(X).T
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, w_lags, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w, w_lags=w_lags)
+        reg = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w.sparse, w_lags=w_lags)
         betas = np.array([[  4.53017056e+01], [  6.20888617e-01], [ -4.80723451e-01], [  2.83622122e-02]])
         np.testing.assert_array_almost_equal(reg.betas, betas, 7)
         h_0 = np.array([  1.        ,  19.531     ,  15.72598   ,  18.594     ,
@@ -86,7 +86,7 @@ class TestBaseGMLag(unittest.TestCase):
         self.X = np.array(X).T
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, w_lags, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        base_gm_lag = BaseGM_Lag(self.y, self.X,  yend=yd2, q=q2, w=self.w, w_lags=w_lags, robust='white')
+        base_gm_lag = BaseGM_Lag(self.y, self.X,  yend=yd2, q=q2, w=self.w.sparse, w_lags=w_lags, robust='white')
         tbetas = np.array([[  4.53017056e+01], [  6.20888617e-01], [ -4.80723451e-01], [  2.83622122e-02]])
         np.testing.assert_array_almost_equal(base_gm_lag.betas, tbetas) 
         dbetas = D.se_betas(base_gm_lag)
@@ -102,7 +102,7 @@ class TestBaseGMLag(unittest.TestCase):
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, w_lags, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
         gwk = pysal.kernelW_from_shapefile(pysal.examples.get_path('columbus.shp'),k=15,function='triangular', fixed=False)        
-        base_gm_lag = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w, w_lags=w_lags, robust='hac', gwk=gwk)
+        base_gm_lag = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w.sparse, w_lags=w_lags, robust='hac', gwk=gwk)
         tbetas = np.array([[  4.53017056e+01], [  6.20888617e-01], [ -4.80723451e-01], [  2.83622122e-02]])
         np.testing.assert_array_almost_equal(base_gm_lag.betas, tbetas) 
         dbetas = D.se_betas(base_gm_lag)
@@ -119,7 +119,7 @@ class TestBaseGMLag(unittest.TestCase):
         q = np.reshape(q, (49,1))
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, yd, q, w_lags, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = BaseGM_Lag(self.y, self.X, w=self.w, yend=yd2, q=q2, w_lags=w_lags)
+        reg = BaseGM_Lag(self.y, self.X, w=self.w.sparse, yend=yd2, q=q2, w_lags=w_lags)
         tbetas = np.array([[ 100.79359082], [  -0.50215501], [  -1.14881711], [  -0.38235022]])
         np.testing.assert_array_almost_equal(tbetas, reg.betas)
         dbetas = D.se_betas(reg)
@@ -134,7 +134,7 @@ class TestBaseGMLag(unittest.TestCase):
         self.X = np.array(X).T
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, None, None, w_lags, True)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w, w_lags=w_lags, sig2n_k=True)
+        reg = BaseGM_Lag(self.y, self.X, yend=yd2, q=q2, w=self.w.sparse, w_lags=w_lags, sig2n_k=True)
         betas = np.  array([[  4.53017056e+01], [  6.20888617e-01], [ -4.80723451e-01], [  2.83622122e-02]])
         np.testing.assert_array_almost_equal(reg.betas, betas, 7)
         vm = np.array( [[  3.49389596e+02, -5.36394351e+00, -2.81960968e+00, -4.35694515e+00],
@@ -153,7 +153,7 @@ class TestBaseGMLag(unittest.TestCase):
         q = np.reshape(q, (49,1))
         yd2, q2 = pysal.spreg.utils.set_endog(self.y, self.X, self.w, yd, q, w_lags, False)
         self.X = np.hstack((np.ones(self.y.shape),self.X))
-        reg = BaseGM_Lag(self.y, self.X, w=self.w, yend=yd2, q=q2, w_lags=w_lags, lag_q=False)
+        reg = BaseGM_Lag(self.y, self.X, w=self.w.sparse, yend=yd2, q=q2, w_lags=w_lags, lag_q=False)
         tbetas = np.array( [[ 108.83261383], [  -0.48041099], [  -1.18950006], [  -0.56140186]])
         np.testing.assert_array_almost_equal(tbetas, reg.betas)
         dbetas = D.se_betas(reg)
